@@ -360,6 +360,15 @@ class SummarizationType(str, Enum):
     "A single paragraph summarizing the entire transcription text."
 
 
+class SpeechModel(str, Enum):
+    """
+    Used for AssemblyAI's Speech Model feature.
+    """
+
+    nano = "nano"
+    "The Nano tier is a lightweight model that is optimized for speed and cost."
+
+
 class RawTranscriptionConfig(BaseModel):
     language_code: Optional[LanguageCode]
     """
@@ -464,6 +473,11 @@ class RawTranscriptionConfig(BaseModel):
     speech_threshold: Optional[float]
     "Reject audio files that contain less than this fraction of speech. Valid values are in the range [0,1] inclusive"
 
+    speech_model: Optional[SpeechModel]
+    """
+    The speech model to use for the transcription.
+    """
+
     class Config:
         extra = Extra.allow
 
@@ -504,6 +518,7 @@ class TranscriptionConfig:
         language_detection: Optional[bool] = None,
         speech_threshold: Optional[float] = None,
         raw_transcription_config: Optional[RawTranscriptionConfig] = None,
+        speech_model: Optional[SpeechModel] = None,
     ) -> None:
         """
         Args:
@@ -583,6 +598,7 @@ class TranscriptionConfig:
         self.auto_highlights = auto_highlights
         self.language_detection = language_detection
         self.speech_threshold = speech_threshold
+        self.speech_model = speech_model
 
     @property
     def raw(self) -> RawTranscriptionConfig:
@@ -601,6 +617,16 @@ class TranscriptionConfig:
 
         self._raw_transcription_config.language_code = language_code
 
+    @property
+    def speech_model(self) -> Optional[SpeechModel]:
+        "The speech model to use for the transcription."
+        return self._raw_transcription_config.speech_model
+
+    @speech_model.setter
+    def speech_model(self, speech_model: Optional[SpeechModel]) -> None:
+        "Sets the speech model to use for the transcription."
+        self._raw_transcription_config.speech_model = speech_model
+
     @property
     def punctuate(self) -> Optional[bool]:
         "Returns the status of the Automatic Punctuation feature."
@@ -1385,7 +1411,7 @@ class Sentence(Word):
     words: List[Word]
     start: int
     end: int
-    confidence: int
+    confidence: float
     speaker: Optional[str]
 
 
@@ -1399,7 +1425,7 @@ class Paragraph(Word):
     words: List[Word]
     start: int
     end: int
-    confidence: int
+    confidence: float
     text: str
 
 
@@ -1520,6 +1546,9 @@ class BaseTranscript(BaseModel):
     speech_threshold: Optional[float]
     "Reject audio files that contain less than this fraction of speech. Valid values are in the range [0,1] inclusive"
 
+    speech_model: Optional[SpeechModel]
+    "The speech model to use for the transcription."
+
 
 class TranscriptRequest(BaseTranscript):
     """
@@ -1582,6 +1611,9 @@ class TranscriptResponse(BaseTranscript):
     entities: Optional[List[Entity]]
     "When Entity Detection is enabled, the list of detected Entities"
 
+    speech_model: Optional[SpeechModel]
+    "The speech model used for the transcription"
+
     def __init__(self, **data: Any):
         # cleanup the response before creating the object
         if not data.get("iab_categories_result") or (
@@ -1885,6 +1917,25 @@ class RealtimeMessageTypes(str, Enum):
     session_terminated = "SessionTerminated"
 
 
+class AudioEncoding(str, Enum):
+    """
+    The encoding of the audio data
+    """
+
+    pcm_s16le = "pcm_s16le"
+    pcm_mulaw = "pcm_mulaw"
+
+
+class RealtimeCreateTemporaryTokenRequest(BaseModel):
+    expires_in: int
+    "The amount of time until the token expires in seconds"
+
+
+class RealtimeCreateTemporaryTokenResponse(BaseModel):
+    token: str
+    "The temporary authentication token for real-time transcription"
+
+
 class RealtimeSessionOpened(BaseModel):
     """
     Once a real-time session is opened, the client will receive this message
